from django.contrib.auth.decorators import login_required
from django.db import transaction;
from django.shortcuts import render, redirect
from .models import Product, Order, OrderDetail, Cart, CartItem
# Create your views here.
@login_required(login_url='/user/login/')  # Redirects to login if not authenticated
def show_products(request):
    products = Product.objects.all()
    context = {
        "products": products
    }
    return render(request, "product/index.html", context)

@login_required(login_url='/user/login/')  # Redirects to login if not authenticated
def add_product_to_cart(request, product_id):
    product = Product.objects.get(id=product_id)
    cart, created = Cart.objects.get_or_create(user=request.user)
    cart_item, created = CartItem.objects.get_or_create(cart=cart, product=product, defaults={'quantity': 1})
    if not created:
        cart_item.quantity += 1
        cart_item.save()
    return redirect('show_products')

@login_required(login_url='/user/login/')  # Redirects to login if not authenticated
def view_cart(request):
    cart, created = Cart.objects.get_or_create(user=request.user)
    
    cart_items = CartItem.objects.filter(cart=cart)
    for item in cart_items:
        item.subtotal = item.product.price * item.quantity
    total_price = sum(item.subtotal for item in cart_items)
    context = {
        "cart_items": cart_items,
        "total_price": total_price
    }
    return render(request, "product/cart.html", context)

@login_required(login_url='/user/login/')  # Redirects to login if not authenticated
def delete_cart_item(request, item_id):
    cart_item = CartItem.objects.get(id=item_id)
    cart_item.delete()
    return redirect('view_cart')

@login_required(login_url='/user/login/')  # Redirects to login if not authenticated
def checkout(request):
    # Transaction Implementation
    with transaction.atomic():
        cart = request.user.cart
        cart_items = CartItem.objects.filter(cart=cart)
        total_price = sum((
            item.product.price * item.quantity
        ) for item in cart_items)
        order = Order.objects.create(user=request.user, total_price=total_price)
        for item in cart_items:
            subtotal = item.product.price * item.quantity
            OrderDetail.objects.create(order=order, product=item.product, quantity=item.quantity, subtotal=subtotal)
        cart_items.delete()
    return redirect('show_products')

@login_required(login_url='/user/login/')  # Redirects to login if not authenticated
def view_orders(request):
    orders = Order.objects.filter(user=request.user)
    context = {
        "orders": orders
    }
    return render(request, "product/orders.html", context)

@login_required(login_url='/user/login/')  # Redirects to login if not authenticated
def view_order_details(request, order_id):
    order = Order.objects.get(id=order_id)
    order_details = OrderDetail.objects.filter(order=order)
    context = {
        "order": order,
        "order_details": order_details
    }
    return render(request, "product/order_details.html", context)

@login_required(login_url='/user/login/')  # Redirects to login if not authenticated
def delete_order(request, order_id):
    order = Order.objects.get(id=order_id)
    order.delete()
    return redirect('view_orders')