from django.db import models
from django.core.validators import RegexValidator, MinLengthValidator, MaxLengthValidator, EmailValidator, URLValidator
from django.utils import timezone
from django.core.exceptions import ValidationError

class UserProfile(models.Model):
    def clean_tanggal_lahir(value):
        age = (timezone.now().date() - value).days / 365.25
        print(age)
        if age < 12:
            print('Usia pengguna minimal 12 tahun.')
            raise ValidationError('Usia pengguna minimal 12 tahun.')
            

    def validate_and_sanitize_phone(value):
        # check for length
        if not (8 <= len(value) <= 15):
            raise ValidationError('Nomor telepon harus memiliki panjang total antara 8 hingga 15 angka.')
        
        phone_regex = RegexValidator(
            regex=r'^\+?\d{1,3}-?\d{4,15}$',
            message='Nomor telepon harus memiliki format kode negara - nomor telepon atau nomor telepon dengan tanda hubung opsional.'
        )
        phone_regex(value)
        
        # Check total length (excluding + and -)
        sanitized_value = value.replace('+', '').replace('-', '')
        if not (8 <= len(sanitized_value) <= 15):
            raise ValidationError('Nomor telepon harus memiliki panjang total antara 8 hingga 15 angka.')
        
        return value
    
    enum_kategori = {
        'Elektronik': 'Elektronik',
        'Fashion': 'Fashion',
        'Furnitur': 'Furnitur',
        'Obat': 'Obat',
        'Kecantikan': 'Kecantikan'
    }
    
    fullname = models.CharField(
        max_length=255,
        validators=[
            RegexValidator(
                regex=r'^[a-zA-Z0-9._-]+$',
                message='Nama hanya boleh berisi huruf, angka, dan karakter (., _, -).'
            )
        ]
    )
    
    tanggal_lahir = models.DateField(
        validators=[
            RegexValidator(
                regex=r'^\d{4}-\d{2}-\d{2}$',
                message='Tanggal lahir harus dalam format YYYY-MM-DD.'
            ),
            clean_tanggal_lahir
        ]
    )
    nomor_hp = models.CharField(
        max_length=15,
        validators=[
            validate_and_sanitize_phone
        ]
    )
    url_blog = models.CharField(
        max_length=255,
        validators=[URLValidator(message='URL Blog harus sesuai dengan format URL.')]
    )
    deskripsi = models.TextField(
        validators=[
            MinLengthValidator(5),
            MaxLengthValidator(1000)
        ]
    )
    id_penjual = models.CharField(
        max_length=10,
        validators=[
            RegexValidator(
                regex=r'^S-\d{8}$',
                message='ID Penjual harus diawali dengan "S-" diikuti oleh 8 angka.'
            )
        ]
    )
    kategori_produk = models.CharField(
        max_length=50,
        choices=[(tag, tag) for tag in enum_kategori.keys()]
    )
    
    groups = models.ManyToManyField(
        "auth.Group",
        related_name="extendeduser_groups",  # Custom related_name
        blank=True
    )
    user_permissions = models.ManyToManyField(
        "auth.Permission",
        related_name="extendeduser_permissions",  # Custom related_name
        blank=True
    )
    