from django.shortcuts import render, redirect
from django.contrib.auth import login, logout

from .forms import UserProfileForm, UserForm
from django.contrib.auth.forms import AuthenticationForm

def login_view(request):
    if request.method == "POST":
        form = AuthenticationForm(request, data=request.POST)
        if form.is_valid():
            user = form.get_user()
            login(request, user)
            return redirect('home')  # Change 'home' to your desired redirect page
    else:
        form = AuthenticationForm()
    
    return render(request, 'login.html', {'form': form})

def register_view(request):
    if request.method == "POST":
        user_form = UserForm(request.POST)
        profile_form = UserProfileForm(request.POST, request.FILES)
        
        if user_form.is_valid() and profile_form.is_valid():
            user = user_form.save(commit=False)
            user.set_password(user_form.cleaned_data['password'])  # Hash password
            user.save()

            # Create UserProfile linked to the user
            profile = profile_form.save(commit=False)
            profile.user = user
            profile.save()

            login(request, user)  # Log in the user
            return redirect("home")  # Redirect to a dashboard or home page

    else:
        user_form = UserForm()
        profile_form = UserProfileForm()
        
    return render(request, "register.html", {"user_form": user_form, "profile_form": profile_form})

def logout_view(request):
    logout(request)
    return redirect("home")