from django import forms
from django.template.loader import render_to_string

class TailwindInput(forms.Widget):
    template_name = "components/input.html"

    def __init__(self, input_type="text", attrs=None):
        self.input_type = input_type
        super().__init__(attrs)

    def get_context(self, name, value, attrs):
        attrs = attrs or {}
        context = {
            "class": attrs.get("class", "mb-4"),
            "id": attrs.get("id", f"id_{name}"),
            "label": attrs.get("label", name.replace("_", " ").upper()),
            "type": self.input_type,
            "name": name,
            "value": value or "",
            "placeholder": attrs.get("placeholder", ""),
            "step": attrs.get("step", ""),
        }
        return context

    def render(self, name, value, attrs=None, renderer=None):
        context = self.get_context(name, value, attrs)
        return render_to_string(self.template_name, context)
